pkgconfig: Python interface to pkg-config
=========================================

Description
-----------

Pkgconfig is a Python module to interface with the pkg-config command
line tool.

License
-------

MIT License


Upstream Contact
----------------

https://github.com/matze/pkgconfig

Dependencies
------------

-  Python 2.6+


Special Update/Build Instructions
---------------------------------

Standard setup.py

-  remove_nose.patch: Remove the nose dependency (not actually used)
